# Table of Contents

- [provider-modeling-guidelines](<./provider-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Provider Modeling Guidelines](<./Provider-Modeling-Guidelines.md>)
  - [Definition](<./Provider-Modeling-Guidelines/Definition.md>)
  - [Description](<./Provider-Modeling-Guidelines/Description.md>)
  - [Guidelines and Best Practices](<./Provider-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Antipatterns](<./Provider-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Provider-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Provider Fact Sheet](<./Provider-Modeling-Guidelines/Insights-from-Provider-Fact-Sheet.md>)
  - [Related Information](<./Provider-Modeling-Guidelines/Related-Information.md>)
